==> jc-1.4.0.tar.gz: javax/xml/datatype/DatatypeConstants.h <==
// public final class javax.xml.datatype.DatatypeConstants

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3e0da72887676f79 javax_xml_datatype_DatatypeConstants

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_datatype_DatatypeConstants_H_
#define _JC_javax_xml_datatype_DatatypeConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object;
struct _jc_javax_xml_namespace_QName$object;

// Typedefs
typedef struct _jc_javax_xml_datatype_DatatypeConstants$sub_refs	_jc_javax_xml_datatype_DatatypeConstants$sub_refs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants$sub_nonrefs	_jc_javax_xml_datatype_DatatypeConstants$sub_nonrefs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants$refs	_jc_javax_xml_datatype_DatatypeConstants$refs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants$nonrefs	_jc_javax_xml_datatype_DatatypeConstants$nonrefs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants$object	_jc_javax_xml_datatype_DatatypeConstants$object;

typedef struct _jc_javax_xml_datatype_DatatypeConstants$fields_struct	_jc_javax_xml_datatype_DatatypeConstants$fields_struct;
typedef const struct _jc_javax_xml_datatype_DatatypeConstants$vmethods	_jc_javax_xml_datatype_DatatypeConstants$vmethods;
typedef const struct _jc_javax_xml_datatype_DatatypeConstants$vtable	_jc_javax_xml_datatype_DatatypeConstants$vtable;
typedef const struct _jc_javax_xml_datatype_DatatypeConstants$vtype	_jc_javax_xml_datatype_DatatypeConstants$vtype;

// Class fields structure
struct _jc_javax_xml_datatype_DatatypeConstants$fields_struct {
	struct _jc_javax_xml_namespace_QName$object	*DATE;
	struct _jc_javax_xml_namespace_QName$object	*DATETIME;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	*DAYS;
	struct _jc_javax_xml_namespace_QName$object	*DURATION;
	struct _jc_javax_xml_namespace_QName$object	*DURATION__5fDAYTIME;
	struct _jc_javax_xml_namespace_QName$object	*DURATION__5fYEARMONTH;
	struct _jc_javax_xml_namespace_QName$object	*GDAY;
	struct _jc_javax_xml_namespace_QName$object	*GMONTH;
	struct _jc_javax_xml_namespace_QName$object	*GMONTHDAY;
	struct _jc_javax_xml_namespace_QName$object	*GYEAR;
	struct _jc_javax_xml_namespace_QName$object	*GYEARMONTH;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	*HOURS;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	*MINUTES;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	*MONTHS;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	*SECONDS;
	struct _jc_javax_xml_namespace_QName$object	*TIME;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	*YEARS;
	jint	APRIL;
	jint	AUGUST;
	jint	DECEMBER;
	jint	EQUAL;
	jint	FEBRUARY;
	jint	FIELD__5fUNDEFINED;
	jint	GREATER;
	jint	INDETERMINATE;
	jint	JANUARY;
	jint	JULY;
	jint	JUNE;
	jint	LESSER;
	jint	MARCH;
	jint	MAX__5fTIMEZONE__5fOFFSET;
	jint	MAY;
	jint	MIN__5fTIMEZONE__5fOFFSET;
	jint	NOVEMBER;
	jint	OCTOBER;
	jint	SEPTEMBER;
};
extern _jc_javax_xml_datatype_DatatypeConstants$fields_struct _jc_javax_xml_datatype_DatatypeConstants$class_fields;

// Constructors
extern void _jc_javax_xml_datatype_DatatypeConstants$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConstants$object *);

// Static methods
extern void _jc_javax_xml_datatype_DatatypeConstants$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_javax_xml_datatype_DatatypeConstants$vmethods {
};

// Vtable
struct _jc_javax_xml_datatype_DatatypeConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_datatype_DatatypeConstants$vmethods	javax_xml_datatype_DatatypeConstants;
};

// Vtype
struct _jc_javax_xml_datatype_DatatypeConstants$vtype {
	_jc_type			type;
	_jc_javax_xml_datatype_DatatypeConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_datatype_DatatypeConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_datatype_DatatypeConstants$refs {
    _jc_javax_xml_datatype_DatatypeConstants$sub_refs	javax_xml_datatype_DatatypeConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_datatype_DatatypeConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_datatype_DatatypeConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_datatype_DatatypeConstants$sub_nonrefs	javax_xml_datatype_DatatypeConstants;
};

// Object instance structure
struct _jc_javax_xml_datatype_DatatypeConstants$object {
	_jc_javax_xml_datatype_DatatypeConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_datatype_DatatypeConstants$vtype	*vtype;
	_jc_javax_xml_datatype_DatatypeConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_datatype_DatatypeConstants$vtype _jc_javax_xml_datatype_DatatypeConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_datatype_DatatypeConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_datatype_DatatypeConstants$class_object;

#endif	/* _JC_javax_xml_datatype_DatatypeConstants_H_ */

==> jc-1.4.6.tar.gz: javax/xml/datatype/DatatypeConstants.h <==
// public final class javax.xml.datatype.DatatypeConstants

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3e0da72887676f79 javax_xml_datatype_DatatypeConstants

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_xml_datatype_DatatypeConstants_H_
#define _JC_javax_xml_datatype_DatatypeConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object;
struct _jc_javax_xml_namespace_QName$object;

// Typedefs
typedef struct _jc_javax_xml_datatype_DatatypeConstants$sub_refs	_jc_javax_xml_datatype_DatatypeConstants$sub_refs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants$sub_nonrefs	_jc_javax_xml_datatype_DatatypeConstants$sub_nonrefs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants$refs	_jc_javax_xml_datatype_DatatypeConstants$refs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants$nonrefs	_jc_javax_xml_datatype_DatatypeConstants$nonrefs;
typedef struct _jc_javax_xml_datatype_DatatypeConstants$object	_jc_javax_xml_datatype_DatatypeConstants$object;

typedef struct _jc_javax_xml_datatype_DatatypeConstants$fields_struct	_jc_javax_xml_datatype_DatatypeConstants$fields_struct;
typedef const struct _jc_javax_xml_datatype_DatatypeConstants$vmethods	_jc_javax_xml_datatype_DatatypeConstants$vmethods;
typedef const struct _jc_javax_xml_datatype_DatatypeConstants$vtable	_jc_javax_xml_datatype_DatatypeConstants$vtable;
typedef const struct _jc_javax_xml_datatype_DatatypeConstants$vtype	_jc_javax_xml_datatype_DatatypeConstants$vtype;

// Class fields structure
struct _jc_javax_xml_datatype_DatatypeConstants$fields_struct {
	struct _jc_javax_xml_namespace_QName$object	*DATE;
	struct _jc_javax_xml_namespace_QName$object	*DATETIME;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	*DAYS;
	struct _jc_javax_xml_namespace_QName$object	*DURATION;
	struct _jc_javax_xml_namespace_QName$object	*DURATION__5fDAYTIME;
	struct _jc_javax_xml_namespace_QName$object	*DURATION__5fYEARMONTH;
	struct _jc_javax_xml_namespace_QName$object	*GDAY;
	struct _jc_javax_xml_namespace_QName$object	*GMONTH;
	struct _jc_javax_xml_namespace_QName$object	*GMONTHDAY;
	struct _jc_javax_xml_namespace_QName$object	*GYEAR;
	struct _jc_javax_xml_namespace_QName$object	*GYEARMONTH;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	*HOURS;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	*MINUTES;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	*MONTHS;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	*SECONDS;
	struct _jc_javax_xml_namespace_QName$object	*TIME;
	struct _jc_javax_xml_datatype_DatatypeConstants__24Field$object	*YEARS;
	jint	APRIL;
	jint	AUGUST;
	jint	DECEMBER;
	jint	EQUAL;
	jint	FEBRUARY;
	jint	FIELD__5fUNDEFINED;
	jint	GREATER;
	jint	INDETERMINATE;
	jint	JANUARY;
	jint	JULY;
	jint	JUNE;
	jint	LESSER;
	jint	MARCH;
	jint	MAX__5fTIMEZONE__5fOFFSET;
	jint	MAY;
	jint	MIN__5fTIMEZONE__5fOFFSET;
	jint	NOVEMBER;
	jint	OCTOBER;
	jint	SEPTEMBER;
};
extern _jc_javax_xml_datatype_DatatypeConstants$fields_struct _jc_javax_xml_datatype_DatatypeConstants$class_fields;

// Constructors
extern void _jc_javax_xml_datatype_DatatypeConstants$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_xml_datatype_DatatypeConstants$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_xml_datatype_DatatypeConstants$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_xml_datatype_DatatypeConstants$vmethods {
};

// Vtable
struct _jc_javax_xml_datatype_DatatypeConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_datatype_DatatypeConstants$vmethods	javax_xml_datatype_DatatypeConstants;
};

// Vtype
struct _jc_javax_xml_datatype_DatatypeConstants$vtype {
	_jc_type			type;
	_jc_javax_xml_datatype_DatatypeConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_datatype_DatatypeConstants$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_datatype_DatatypeConstants$refs {
    _jc_javax_xml_datatype_DatatypeConstants$sub_refs	javax_xml_datatype_DatatypeConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_datatype_DatatypeConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_datatype_DatatypeConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_datatype_DatatypeConstants$sub_nonrefs	javax_xml_datatype_DatatypeConstants;
};

// Object instance structure
struct _jc_javax_xml_datatype_DatatypeConstants$object {
	_jc_javax_xml_datatype_DatatypeConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_datatype_DatatypeConstants$vtype	*vtype;
	_jc_javax_xml_datatype_DatatypeConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_datatype_DatatypeConstants$vtype _jc_javax_xml_datatype_DatatypeConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_datatype_DatatypeConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_datatype_DatatypeConstants$class_object;

#endif	/* _JC_javax_xml_datatype_DatatypeConstants_H_ */
